package me.picnicapp.sample.picnicsample;

import java.util.ArrayList;

import me.picnicapp.sdk.content.Content;
import me.picnicapp.sdk.content.ContentLoader;
import me.picnicapp.sdk.picnic.Picnic;

public class App extends Picnic {

    // picnicの初期化処理
    @Override
    public void initializePicnic() {
        // アプリキーを設定する
        setApplicationKey("your_app_key");

        // コンテンツをpicnicSDKに登録する
        ArrayList<Content> contents = ContentLoader.readJsonFromResource(this, R.raw.contents);
        getContentsManager().setContents(contents);

        // ■ARと地図画面から呼び出される、使い方画面を指定する
        getSettings().common().setHowtoActivity(HowToActivity.class);

        // ■AR画面の初期設定を行う
        // カメラの画角
        getSettings().ar().setViewAngle(35);
        // 一度に表示するコンテンツ数の上限を指定する
        // (1度に大量のコンテンツを表示するとカメラがコンテンツで埋もれてしまうため)
        getSettings().ar().setDisplayContentsLimit(20);
        // カメラに浮かぶARタグは、距離によってサイズが変わる。
        // 現在位置から近いほど大きく表示される。
        // コンテンツに近づいた時に、ARタグが最大サイズで表示される距離を設定する。
        getSettings().ar().setMaxSizeDistance(30);
        // カメラに浮かぶARタグは、距離によってサイズが変わる。
        // 現在位置から遠いほど小さく表示される。
        // コンテンツから離れた時に、ARタグが表示されなくなる距離を設定する。
        getSettings().ar().setMinSizeDistance(300);
        // コンテンツに近づいた際の、ARタグの最大表示サイズ
        getSettings().ar().setMaxSizeRatio(0.4f);
        // コンテンツから遠ざかって、表示範囲ギリギリになった際の、ARタグの最小表示サイズ
        getSettings().ar().setMinSizeRatio(0.1f);
        // 地図画面に移動するボタンをAR画面上に表示するか
        getSettings().ar().setIsVisibleMapButton(true);

        // ■地図画面の初期設定を行う
        // 緯度
        getSettings().map().setInitialLatitude(35.689560d);
        // 経度
        getSettings().map().setInitialLongitude(139.691783d);
        // 地図拡大率(2〜21で指定。数値が大きほど拡大表示される。)
        getSettings().map().setInitialZoomLevel(17f);
        // AR画面に移動するボタンを地図画面上に表示するか
        getSettings().map().setIsVisibleARButton(true);

        // ■コンテンツ一覧画面の初期設定を行う
        getSettings().contentList().setIsDirectCamera(false);

        // ■コンテンツ詳細画面の初期設定を行う
        getSettings().contentDetail().setIsPictureEnabled(true);
        getSettings().contentDetail().setEnablePictureDistance(0);
    }
}
